summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsopaqueproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsopaqueproxy.h')
-rw-r--r--kjsembed/jsopaqueproxy.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kjsembed/jsopaqueproxy.h b/kjsembed/jsopaqueproxy.h
index fdad268b..eb446169 100644
--- a/kjsembed/jsopaqueproxy.h
+++ b/kjsembed/jsopaqueproxy.h
@@ -19,8 +19,8 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef KJSEMBEDJSOPAQUEPROXY_H
-#define KJSEMBEDJSOPAQUEPROXY_H
+#ifndef KJSEMBEDJSOPATQUEPROXY_H
+#define KJSEMBEDJSOPATQUEPROXY_H
#include <tqcstring.h>
#include <tqevent.h>
@@ -31,7 +31,7 @@
#include <algorithm>
#include <typeinfo>
-class TQTextStream;
+class TTQTextStream;
namespace KJSEmbed {
@@ -57,16 +57,16 @@ public:
}
/** Creates an opaque proxy. */
- JSOpaqueProxy( TQTextStream *ts );
+ JSOpaqueProxy( TTQTextStream *ts );
/** Creates an opaque proxy. */
- JSOpaqueProxy( const TQEvent *ev );
+ JSOpaqueProxy( const TTQEvent *ev );
/** Cleans up. */
virtual ~JSOpaqueProxy();
/** Returns the type of the wrapped object.*/
- TQString typeName() const;
+ TTQString typeName() const;
/** Sets the value of the proxy and its type. */
template<typename T>
@@ -79,11 +79,11 @@ public:
ptrtype = ptype ? ptype : "void";
}
- /** Sets the value of the proxy to a TQTextStream. */
- void setValue( TQTextStream *ts );
+ /** Sets the value of the proxy to a TTQTextStream. */
+ void setValue( TTQTextStream *ts );
- /** Sets the value of the proxy to a TQEvent. */
- void setValue( const TQEvent *ev );
+ /** Sets the value of the proxy to a TTQEvent. */
+ void setValue( const TTQEvent *ev );
/** Returns the proxy value as a pointer. */
template<typename T>
@@ -98,12 +98,12 @@ public:
bool inherits( const char *clazz );
/**
* Returns the TQTextStream stored in the proxy. If proxy does not contain
* a value of type TQTextStream then 0 is returned.
*/
- TQTextStream *toTextStream();
+ TTQTextStream *toTextStream();
- const TQEvent *toEvent();
+ const TTQEvent *toEvent();
/** Adds the bindings for the opaque proxy to the specified js object. */
virtual void addBindings( KJS::ExecState *state, KJS::Object &object );
@@ -113,9 +113,9 @@ public:
private:
- TQTextStream *textstream;
- const TQEvent *event;
- TQCString ptrtype;
+ TTQTextStream *textstream;
+ const TTQEvent *event;
+ TTQCString ptrtype;
class JSOpaqueProxyPrivate *d;
@@ -165,7 +165,7 @@ private:
} // namespace KJSEmbed
-#endif // KJSEMBEDJSOPAQUEPROXYIMP_H
+#endif // KJSEMBEDJSOPATQUEPROXYIMP_H
// Local Variables:
// c-basic-offset: 4
@@ -98,12 +98,12 @@ public:
bool inherits( const char *clazz );
/**
- * Returns the TQTextStream stored in the proxy. If proxy does not contain
- * a value of type TQTextStream then 0 is returned.
+ * Returns the TTQTextStream stored in the proxy. If proxy does not contain
+ * a value of type TTQTextStream then 0 is returned.
*/